@@ -737,6 +737,50 @@ class SubProjectsHandler(BaseHandler):
             self.error_response(500, "ServerError", str(se))
 
 
+
+class ContainersHandler(BaseHandler):
+
+    @tornado.web.authenticated
+    async def post(self):
+        """
+        Handler for listing the notebook runs.
+        """
+        try:
+            # await self.tracker.update()
+            data = json.loads(self.request.body.decode("utf-8"))
+            self.log.debug(f'runs data: {data}')
+            if data is None:
+                self.error_response(404, "ServerError",
+                                    "DataPlate Configuration is invalid, please set your Server URL and Access Key")
+                return
+
+            serverURL = data.get("serverURL", "")
+            accessKey = data.get("accessKey", "")
+
+            if not serverURL or not accessKey or serverURL == "" or accessKey == "":
+                self.error_response(404, "ServerError",
+                                    "DataPlate Configuration is invalid, please set your Server URL and Access Key")
+                return
+
+            containers = []
+            dataplate = DataPlate(access_key=accessKey, dataplate_uri=serverURL)
+            generator = dataplate.list_containers(n=100)
+            for container in json.loads(generator.reset_index().to_json(orient='records')):
+                # self.log.debug(f'Described run job: {run["name"]}')
+                await asyncio.sleep(0)
+                containers.append(container)
+
+            self.json_response({"containers": containers})
+        except botocore.exceptions.ClientError as e:
+            self.client_error_response(e)
+        except botocore.exceptions.BotoCoreError as e:
+            self.botocore_error_response(e)
+        except Exception as ex:
+            self.error_response(500, "ServerError", str(ex))
+        except SystemExit as se:
+            self.error_response(500, "ServerError", str(se))
+
+
 class ScanHandler(BaseHandler):
 
     @tornado.web.authenticated
@@ -845,13 +889,14 @@ def setup_handlers(web_app):
     invoke_pattern = url_path_join(base_url, prefix, "run")
     datasets_pattern = url_path_join(base_url, prefix, "datasets")
     projects_pattern = url_path_join(base_url, prefix, "projects")
+    containers_pattern = url_path_join(base_url, prefix, "containers")
     subprojects_pattern = url_path_join(base_url, prefix, "subprojects/(.+)")
     scan_pattern = url_path_join(base_url, prefix, "scan/(.+)")
     reportstatistics_pattern = url_path_join(base_url, prefix,"reportstatistics")
     handlers = [(route_pattern, RouteHandler), (schedule_pattern, RulesHandler),(schedule_details_pattern,RuleHandler),
                 (run_details_pattern,RunHandler),(runs_pattern,RunsHandler),(output_pattern,OutputHandler),(invoke_pattern,InvokeHandler),
-                (datasets_pattern,DatasetsHandler),(projects_pattern,ProjectsHandler),(subprojects_pattern,SubProjectsHandler),(scan_pattern,ScanHandler),
-                (reportstatistics_pattern,ReportStatisticsHandler)]
+                (datasets_pattern,DatasetsHandler),(projects_pattern,ProjectsHandler),(containers_pattern,ContainersHandler),
+                (subprojects_pattern,SubProjectsHandler),(scan_pattern,ScanHandler),(reportstatistics_pattern,ReportStatisticsHandler)]
 
     # prefix = "/dataplate-lab/"
     # handlers = [
