@@ -52,6 +52,7 @@ import { JupyterFrontEnd, ILabShell } from '@jupyterlab/application';
 import { RulesModel } from '../models/RulesModel';
 import {DatasetsModel} from "../models/DatasetsModel";
 import {ProjectsModel} from "../models/ProjectsModel";
+import {ContainersModel} from "../models/ContainersModel";
 
 const KEY = 'dataplate-lab:schedule-sidebar:data';
 
@@ -63,6 +64,7 @@ export interface ISchedulePanelProps {
   rulesModel: RulesModel;
   datasetsModel: DatasetsModel;
   projectsModel: ProjectsModel;
+  containersModel: ContainersModel;
   stateDB: IStateDB;
 }
 
@@ -221,6 +223,13 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
               value="Projects"
               onClick={this.onProjectListClick}
             />
+            <input
+              className={sidebarButtonClass}
+              type="button"
+              title="View containers"
+              value="Containers"
+              onClick={this.onContainerListClick}
+            />
             {/*<input*/}
             {/*  className={sidebarButtonClass}*/}
             {/*  type="button"*/}
@@ -522,6 +531,11 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
       this.app.commands.execute('dataplate-lab:open_list_projects');
   };
 
+  private onContainerListClick = async (): Promise<void> => {
+      this.props.containersModel.setDataplateServerKey(this.state.serverURL,this.state.accessKey)
+      this.app.commands.execute('dataplate-lab:open_list_containers');
+  };
+
 
   private onRunClick = async (): Promise<void> => {
     console.log('Run Now');
