@@ -170,3 +170,12 @@ export interface StatisticsReportRequest {
 export interface StatisticsReportResponse {
   report_name: string;
 }
+
+export interface Container {
+  Name: string;
+  LastModified: string;
+}
+
+export interface ListContainersResponse {
+  containers: Container[];
+}
\ No newline at end of file
